/* 
 * MFD-Durchschalter:
 * Tastet direkt nach dem Start (= Zuendung ein) ein Relais parallel 
 * zum MFD-Taster (Golf/Passat) fuenfmal durch, um direkt die ltemperatur 
 * im Display erscheinen zu lassen.
 * 
 * MCU: ATtiny 13 
 * Takt: 16 Khz
 *
 * 16. April 2010 DL1DOW
 */

#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include <avr/sleep.h>

#define LED_GN PB0   /* High-aktiv */
#define LED_GE PB1   /* High-aktiv */
#define RELAIS PB2   /* High-aktiv */
#define SENSE  PB4   /* Zuendung */

#define WAITTIME_BEFORE_START 100 // 10*Millisekunden
#define NUM_CYCLES 5              // Anzahl der Tastzyklen
#define HI_TIME 100               // Millisekunden; Zeit, die Relais angezogen bleibt
#define LO_TIME 500               // Millisekunden; Zeit die Relais hat abzufallen




int main()
{
	// I/O-Pins
	DDRB |= ( (1 << LED_GN) | (1 << LED_GE)) | (1 << RELAIS);
		

	// Stromsparoptionen:
	ADCSRA &= ~(1 << ADEN);  // - ADC aus (S. 81 Datenblatt)
	ACSR |= (1 << ACD);      // - Analog Comperator aus (S.78): Automatisch im "Power Down-Modus" aus
	// - Brown-Out detector (S.36)
	// - Interne Referenzspannung (S. 37)
	// - Watchdog Timer
	// - Port-Pins aus (S. 52), S. 80

	// Startzustand
     
    // 500ms Warten bevor starten
	for (uint8_t i=WAITTIME_BEFORE_START; i > 0; i--)
     {
       _delay_ms(10);
	 }

    
	// X-mal Relais kurz durchschalten
	for (uint8_t i = NUM_CYCLES; i > 0; i--)
	{
	   PORTB |= (1 << LED_GN) | (1 << RELAIS);
       _delay_ms(HI_TIME);
  	   PORTB &= ~((1 << LED_GN) | (1 << RELAIS));
	   _delay_ms(LO_TIME);
    }	


    // Das wars. Warten bis zum nchsten Neustart
	set_sleep_mode(SLEEP_MODE_PWR_DOWN); 
    sleep_enable();
    sleep_cpu();


	while(1);

	return 0;
} // Ende main






